@@ -32,6 +32,7 @@ void CylinderInfoWidget::initUI()
 
     int initCount = 360;
     if (initCount > m_cylNumber) {
+        qDebug() << "[CylinderInfoWidget] Cylinder count is less than 360, set initCount to cylinder count:" << m_cylNumber;
         initCount = m_cylNumber;
     }
 
@@ -143,6 +144,7 @@ void CylinderInfoWidget::initUI()
     setLayout(mainLayout);
 
     m_settings = new QSettings("/tmp/CheckData.conf", QSettings::IniFormat, this);
+    qDebug() << "[CylinderInfoWidget] CylinderInfoWidget initialized.";
 }
 
 void CylinderInfoWidget::initConnections()
@@ -153,27 +155,34 @@ void CylinderInfoWidget::initConnections()
 
 void CylinderInfoWidget::againVerify(int cylNumber)
 {
+    qDebug() << "[CylinderInfoWidget] againVerify called with cylinder number:" << cylNumber;
     m_curCheckCount = 0;
     m_badSectorsCount = 0;
     m_scrollBar->hide();
     m_isChanged = false;
     m_startCylinder = m_settings->value("SettingData/BlockStart").toInt();
     m_endCylinder = m_settings->value("SettingData/BlockEnd").toInt();
+    qDebug() << "[CylinderInfoWidget] Initialized for re-verification, start cylinder:" << m_startCylinder << ", end cylinder:" << m_endCylinder;
 
     QList<QObject *> lstCylinderWidget = m_widget->children();
+    qDebug() << "[CylinderInfoWidget] Current cylinder widget count:" << lstCylinderWidget.count();
 
     if (cylNumber <= lstCylinderWidget.count() - 1) { // 当将要重新检测的个数小于等于360时
+        qDebug() << "[CylinderInfoWidget] Number to verify is less than or equal to current widget count (<=360), resetting existing widgets.";
         for (int i = 1; i < lstCylinderWidget.count(); i ++) {
             CylinderWidget *cylinderWidget = static_cast<CylinderWidget *>(lstCylinderWidget.at(i));
             cylinderWidget->setStyleSheet(QString("background:%1;border:0px").arg(m_initColor));
             cylinderWidget->setUserData("");
+            qDebug() << "[CylinderInfoWidget] Resetting widget at index:" << i;
         }
     } else { // 当将要重新检测的个数大于360
+        qDebug() << "[CylinderInfoWidget] Number to verify is greater than 360, recreating up to 360 widgets.";
         for (int i = 0; i < 360; i ++) {
             if (i < lstCylinderWidget.count() - 1) {
                 CylinderWidget *cylinderWidget = static_cast<CylinderWidget *>(lstCylinderWidget.at(i + 1));
                 cylinderWidget->setStyleSheet(QString("background:%1;border:0px").arg(m_initColor));
                 cylinderWidget->setUserData("");
+                qDebug() << "[CylinderInfoWidget] Resetting existing widget at index:" << i;
             }else {
                 CylinderWidget *cylinderWidget = new CylinderWidget;
                 cylinderWidget->setFixedSize(20, 20);
@@ -182,30 +191,36 @@ void CylinderInfoWidget::againVerify(int cylNumber)
                 cylinderWidget->setStyleSheet(QString("background:%1;border:0px").arg(m_initColor));
                 connect(cylinderWidget, &CylinderWidget::enter, this, &CylinderInfoWidget::enterSlot);
                 connect(cylinderWidget, &CylinderWidget::leave, this, &CylinderInfoWidget::leaveSlot);
-
+                // qDebug() << "[CylinderInfoWidget] Adding new widget at index:" << i;
                 m_gridLayout->addWidget(cylinderWidget, i / 24, i % 24);
             }
 
         }
     }
-
+    qDebug() << "[CylinderInfoWidget] againVerify completed.";
 }
 
 void CylinderInfoWidget::reset(int cylNumber)
 {
+    qDebug() << "[CylinderInfoWidget] reset called with cylinder number:" << cylNumber;
     m_curCheckCount = 0;
     m_badSectorsCount = 0;
     m_scrollBar->hide();
     m_isChanged = false;
+    qDebug() << "[CylinderInfoWidget] Resetting internal state: curCheckCount, badSectorsCount, scrollBar hidden, isChanged to false.";
 
     QList<QObject *> lstCylinderWidget = m_widget->children();
+    qDebug() << "[CylinderInfoWidget] Current cylinder widget count for reset:" << lstCylinderWidget.count();
     for (int i = 1; i < lstCylinderWidget.count(); i ++) {
         QObject *obj = lstCylinderWidget.at(i);
+        qDebug() << "[CylinderInfoWidget] Deleting cylinder widget object at index:" << i;
         delete obj;
         obj = nullptr;
     }
+    qDebug() << "[CylinderInfoWidget] All existing cylinder widgets deleted.";
 
     if (cylNumber <= 360) {
+        qDebug() << "[CylinderInfoWidget] Cylinder number <= 360, recreating widgets up to:" << cylNumber;
         for (int i = 0; i < cylNumber; i++) {
             CylinderWidget *cylinderWidget = new CylinderWidget;
             cylinderWidget->setFixedSize(20, 20);
@@ -214,10 +229,11 @@ void CylinderInfoWidget::reset(int cylNumber)
             cylinderWidget->setStyleSheet(QString("background:%1;border:0px").arg(m_initColor));
             connect(cylinderWidget, &CylinderWidget::enter, this, &CylinderInfoWidget::enterSlot);
             connect(cylinderWidget, &CylinderWidget::leave, this, &CylinderInfoWidget::leaveSlot);
-
+            qDebug() << "[CylinderInfoWidget] Adding new cylinder widget for index:" << i;
             m_gridLayout->addWidget(cylinderWidget, i / 24, i % 24);
         }
     } else {
+        qDebug() << "[CylinderInfoWidget] Cylinder number > 360, recreating 360 widgets.";
         for (int i = 0; i < 360; i++) {
             CylinderWidget *cylinderWidget = new CylinderWidget;
             cylinderWidget->setFixedSize(20, 20);
@@ -226,20 +242,22 @@ void CylinderInfoWidget::reset(int cylNumber)
             cylinderWidget->setStyleSheet(QString("background:%1;border:0px").arg(m_initColor));
             connect(cylinderWidget, &CylinderWidget::enter, this, &CylinderInfoWidget::enterSlot);
             connect(cylinderWidget, &CylinderWidget::leave, this, &CylinderInfoWidget::leaveSlot);
-
+            qDebug() << "[CylinderInfoWidget] Adding new cylinder widget for index:" << i;
             m_gridLayout->addWidget(cylinderWidget, i / 24, i % 24);
         }
     }
-
+    qDebug() << "[CylinderInfoWidget] reset completed.";
 }
 
 void CylinderInfoWidget::setChecked(bool isCheck)
 {
+    qDebug() << "[CylinderInfoWidget] setChecked called with:" << isCheck;
     m_isCheck = isCheck;
 }
 
 void CylinderInfoWidget::setCylinderNumber(int cylNumber)
 {
+    qDebug() << "[CylinderInfoWidget] setCylinderNumber called with:" << cylNumber;
     m_cylNumber = cylNumber;
     m_curCheckCount = 0;
     m_badSectorsCount = 0;
@@ -247,26 +265,33 @@ void CylinderInfoWidget::setCylinderNumber(int cylNumber)
     m_isChanged = false;
     m_startCylinder = m_settings->value("SettingData/BlockStart").toInt();
     m_endCylinder = m_settings->value("SettingData/BlockEnd").toInt();
+    qDebug() << "[CylinderInfoWidget] Initialized m_startCylinder:" << m_startCylinder << "m_endCylinder:" << m_endCylinder;
 
     QList<QObject *> lstCylinderWidget = m_widget->children();
+    qDebug() << "[CylinderInfoWidget] Current cylinder widget count:" << lstCylinderWidget.count();
 
     if (m_cylNumber == lstCylinderWidget.count() - 1) { // 当前要检测的柱面数等于初始化个数
+        qDebug() << "[CylinderInfoWidget] Current cylinder number equals initialized count, returning.";
         return;
     }
 
     if (m_cylNumber > lstCylinderWidget.count() - 1 && (lstCylinderWidget.count() - 1 == 360)) { // 初始化个数为360并且当前要检测的柱面数大于初始化个数
+        qDebug() << "[CylinderInfoWidget] Initialized count is 360 and current cylinder number is greater, returning.";
         return;
     }
 
     if (m_cylNumber < lstCylinderWidget.count() - 1) { // 当前要检测的柱面数小于初始化个数
+        qDebug() << "[CylinderInfoWidget] Current cylinder number is less than initialized count, deleting excess widgets.";
         for (int i = 1; i < lstCylinderWidget.count(); i ++) {
             if(i > m_cylNumber) {
                 QObject *obj = lstCylinderWidget.at(i);
+                qDebug() << "[CylinderInfoWidget] Deleting cylinder widget at index:" << i;
                 delete obj;
                 obj = nullptr;
             }
         }
     } else if((m_cylNumber > lstCylinderWidget.count() - 1) && (m_cylNumber < 360)){ // 当前要检测的柱面数大于初始化个数且当前要检测的柱面数不到360个时
+        qDebug() << "[CylinderInfoWidget] Current cylinder number is greater than initialized count but less than 360, recreating widgets.";
         for (int i = 1; i < lstCylinderWidget.count(); i ++) {
             QObject *obj = lstCylinderWidget.at(i);
             delete obj;
@@ -285,8 +310,10 @@ void CylinderInfoWidget::setCylinderNumber(int cylNumber)
             m_gridLayout->addWidget(cylinderWidget, i / 24, i % 24);
         }
     } else { // 当前要检测的柱面数大于初始化个数且当前要检测的柱面数大于360个时，只显示360个柱面块
+        qDebug() << "[CylinderInfoWidget] Current cylinder number is greater than 360, displaying only 360 widgets.";
         for (int i = 1; i < lstCylinderWidget.count(); i ++) {
             QObject *obj = lstCylinderWidget.at(i);
+            qDebug() << "[CylinderInfoWidget] Deleting existing widget at index:" << i;
             delete obj;
             obj = nullptr;
         }
@@ -315,62 +342,77 @@ void CylinderInfoWidget::setCurCheckBadBlocksInfo(const QString &LBANumber, cons
         qWarning() << "[CylinderInfoWidget] Bad sector detected - LBA:" << LBANumber
                   << "Cylinder:" << cylinderNumber;
         ++m_badSectorsCount;
+        qDebug() << "[CylinderInfoWidget] Bad sectors count incremented to:" << m_badSectorsCount;
     }
 
     if (m_checkData.count() >= 360) {
+        qDebug() << "[CylinderInfoWidget] Check data count >= 360, removing first element.";
         m_checkData.removeFirst();
         m_cylNumberData.removeFirst();
     }
     m_cylNumberData << cylinderNumber;
     m_checkData << QString("%1,%2,%3,%4,%5,0").arg(LBANumber).arg(cylinderNumber).arg(cylinderTimeConsuming).arg(cylinderStatus).arg(cylinderErrorInfo);
+    qDebug() << "[CylinderInfoWidget] Added current check data:" << cylinderNumber;
 
     if (m_isChanged) {
+        qDebug() << "[CylinderInfoWidget] m_isChanged is true, skipping update.";
         return;
     }
 
 //    int startCylinder = m_settings->value("SettingData/BlockStart").toInt();
     if (m_cylNumber <= 360) {
+        qDebug() << "[CylinderInfoWidget] Cylinder number <= 360, updating cylinder info directly.";
         updateCylinderInfo((cylinderNumber.toInt() - m_startCylinder) % 360, LBANumber, cylinderNumber, cylinderTimeConsuming, cylinderStatus, cylinderErrorInfo, "0");
     } else {
+        qDebug() << "[CylinderInfoWidget] Cylinder number > 360, checking curCheckCount.";
         if (m_curCheckCount <= 360) {
+            qDebug() << "[CylinderInfoWidget] curCheckCount <= 360, updating cylinder info directly.";
             updateCylinderInfo((cylinderNumber.toInt() - m_startCylinder) % 360, LBANumber, cylinderNumber, cylinderTimeConsuming, cylinderStatus, cylinderErrorInfo, "0");
         }else {
-
+            qDebug() << "[CylinderInfoWidget] curCheckCount > 360, handling scroll bar and widget updates.";
             int rowCount = m_curCheckCount / 24;
 
             if ( m_curCheckCount % 24 != 0) {
                 rowCount = m_curCheckCount / 24 + 1;
+                qDebug() << "[CylinderInfoWidget] rowCount adjusted for remainder:" << rowCount;
             }
             m_scrollBar->setRange(0, rowCount - 15);
+            qDebug() << "[CylinderInfoWidget] Scroll bar range set to (0, " << rowCount - 15 << ").";
 
             if (!m_isChanged) {
+                qDebug() << "[CylinderInfoWidget] m_isChanged is false, proceeding with scroll bar and widget updates.";
                 if (rowCount > 15) {
                     m_scrollBar->setValue(rowCount - 15);
                     m_scrollBar->setGeometry(600, 0, 18, 390);
                     m_scrollBar->show();
+                    qDebug() << "[CylinderInfoWidget] Scroll bar shown and value set:" << rowCount - 15;
                 }
 
                 QList<QObject *> lstCylinderWidget = m_widget->children();
                 int start = (rowCount - 15) * 24 + m_startCylinder;
+                qDebug() << "[CylinderInfoWidget] Recalculated start index for widgets:" << start;
                 for (int i = start; i < start + 360; i ++) {
                     if (-1 != m_cylNumberData.indexOf(QString("%1").arg(i))) {
                         QString value = m_checkData.at(m_cylNumberData.indexOf(QString("%1").arg(i)));
                         QStringList lst = value.split(",");
                         updateCylinderInfo((i - start) % 360, lst.at(0), lst.at(1), lst.at(2), lst.at(3), lst.at(4), lst.at(5));
+                        qDebug() << "[CylinderInfoWidget] Updating existing widget with data for cylinder:" << i;
                     } else {
                         if (i > m_endCylinder) {
                             CylinderWidget *cylinderWidget = m_widget->findChild<CylinderWidget *>(QString("%1").arg((i - start) % 360));
                             delete cylinderWidget;
                             cylinderWidget = nullptr;
+                            qDebug() << "[CylinderInfoWidget] Deleting cylinder widget for out of range cylinder:" << i;
                         } else {
                             updateCylinderInfo((i - start) % 360, "", "", "", "", "", "");
+                            qDebug() << "[CylinderInfoWidget] Resetting cylinder widget for cylinder:" << i;
                         }
                     }
                 }
             }
         }
     }
-
+    qDebug() << "[CylinderInfoWidget] setCurCheckBadBlocksInfo completed.";
 //    if (m_cylNumber == m_curCheckCount) {
 //        emit checkCoomplete(m_badSectorsCount);
 //    }
@@ -383,20 +425,25 @@ void CylinderInfoWidget::updateCylinderInfo(int number, const QString &LBANumber
     CylinderWidget *cylinderWidget = m_widget->findChild<CylinderWidget *>(QString("%1").arg(number));
 
     if(cylinderWidget == nullptr) {
-        qWarning() << "[CylinderInfoWidget] Cylinder widget not found for number:" << number;
+        qWarning() << "[CylinderInfoWidget] Cylinder widget not found for number:" << number << ", returning.";
         return;
     }
 
     if (LBANumber.isEmpty()) {
+        qDebug() << "[CylinderInfoWidget] LBA number is empty, resetting widget style.";
         cylinderWidget->setStyleSheet(QString("background:%1;border:0px").arg(m_initColor));
         cylinderWidget->setUserData("");
 
     } else {
+        qDebug() << "[CylinderInfoWidget] LBA number is not empty, updating widget based on status.";
         if (cylinderStatus == "good") {
+            qDebug() << "[CylinderInfoWidget] Cylinder status is good, setting excellent color.";
             cylinderWidget->setStyleSheet(QString("background:%1;border:0px").arg(m_excellentColor));
         } else if (cylinderStatus == "bad") {
+            qDebug() << "[CylinderInfoWidget] Cylinder status is bad, setting damaged color.";
             cylinderWidget->setStyleSheet(QString("background:%1;border:0px").arg(m_damagedColor));
         } else {
+            qDebug() << "[CylinderInfoWidget] Cylinder status is unknown, setting unknown color.";
             cylinderWidget->setStyleSheet(QString("background:%1;border:0px").arg(m_unknownColor));
         }
 
@@ -409,41 +456,52 @@ void CylinderInfoWidget::updateCylinderInfo(int number, const QString &LBANumber
         mapInfo["repair"] = repair;
 
         cylinderWidget->setUserData(mapInfo);
+        qDebug() << "[CylinderInfoWidget] Widget user data updated.";
     }
+    qDebug() << "[CylinderInfoWidget] updateCylinderInfo completed.";
 }
 
 void CylinderInfoWidget::setCurRepairBadBlocksInfo(const QString &cylinderNumber)
 {
+    qDebug() << "[CylinderInfoWidget] setCurRepairBadBlocksInfo called for cylinder:" << cylinderNumber;
     QList<QObject *> lstCylinderWidget = m_widget->children();
+    qDebug() << "[CylinderInfoWidget] Current cylinder widget count:" << lstCylinderWidget.count();
 
     if (lstCylinderWidget.count() < 2) {
+        qDebug() << "[CylinderInfoWidget] Less than 2 cylinder widgets, returning.";
         return;
     }
 
     CylinderWidget *firstWidget = static_cast<CylinderWidget *>(lstCylinderWidget.at(1));
     QMap<QString, QVariant> firstValue = firstWidget->getUserData().toMap();
+    qDebug() << "[CylinderInfoWidget] First widget number:" << firstValue["number"].toInt();
 
     CylinderWidget *lastWidget = static_cast<CylinderWidget *>(lstCylinderWidget.at(lstCylinderWidget.count() - 1));
     QMap<QString, QVariant> lastValue = lastWidget->getUserData().toMap();
+    qDebug() << "[CylinderInfoWidget] Last widget number:" << lastValue["number"].toInt();
     if (firstValue["number"].toInt() > cylinderNumber.toInt() || lastValue["number"].toInt() < cylinderNumber.toInt()) {
+        qDebug() << "[CylinderInfoWidget] Cylinder number out of current widget range, returning.";
         return;
     }
 
     for (int i = 1; i < lstCylinderWidget.count(); i++) {
         CylinderWidget *cylinderWidget = static_cast<CylinderWidget *>(lstCylinderWidget.at(i));
         QMap<QString, QVariant> mapInfo = cylinderWidget->getUserData().toMap();
+        qDebug() << "[CylinderInfoWidget] Checking widget at index:" << i << ", number:" << mapInfo["number"].toInt();
 
         if (mapInfo["number"].toInt() == cylinderNumber.toInt()) {
+            qDebug() << "[CylinderInfoWidget] Matching cylinder found, updating style and user data.";
             cylinderWidget->setStyleSheet(QString("background:%1;border:0px").arg(m_excellentColor));
             QString curCheckData = m_settings->value(QString("CheckData/%1").arg(cylinderNumber)).toString();
             QStringList lstCheckData = curCheckData.split(",");
             mapInfo["status"] = lstCheckData.at(3);
             mapInfo["repair"] = lstCheckData.at(5);
             cylinderWidget->setUserData(mapInfo);
+            qDebug() << "[CylinderInfoWidget] Widget updated, status:" << mapInfo["status"].toString() << ", repair:" << mapInfo["repair"].toString();
             break;
         }
     }
-
+    qDebug() << "[CylinderInfoWidget] setCurRepairBadBlocksInfo completed.";
 }
 
 void CylinderInfoWidget::enterSlot()
@@ -454,9 +512,11 @@ void CylinderInfoWidget::enterSlot()
     QMap<QString, QVariant> mapInfo = label->getUserData().toMap();
 
     if (mapInfo.isEmpty()) {
+        qDebug() << "[CylinderInfoWidget] mapInfo is empty, returning from enterSlot.";
         return;
     }
 
+    qDebug() << "[CylinderInfoWidget] Setting LBA label text.";
     m_LBALabel->setText(QString(tr("LBA: %1")).arg(mapInfo["id"].toString())); // LBA
     m_cylNumberLabel->setText(QString(tr("Cyl.: %1")).arg(mapInfo["number"].toString())); // 柱面号
     m_curErrorInfoLabel->setText(QString(tr("Error: %1")).arg(mapInfo["errorinfo"].toString())); // 当前错误信息
@@ -464,21 +524,25 @@ void CylinderInfoWidget::enterSlot()
     m_repairLabel->setText(tr("Status: Repaired")); // 修复情况：已修复
 
     if (mapInfo["repair"].toInt() == 1) {
+        qDebug() << "[CylinderInfoWidget] Repair status is 1, showing error and repair, hiding elapsed time.";
         m_curErrorInfoLabel->show();
         m_repairLabel->show();
         m_elapsedTimeLabel->hide();
     } else {
         if (mapInfo["status"].toString() == "good") {
+            qDebug() << "[CylinderInfoWidget] Status is good, hiding error and repair, showing elapsed time.";
             m_curErrorInfoLabel->hide();
             m_repairLabel->hide();
             m_elapsedTimeLabel->show();
         } else {
+            qDebug() << "[CylinderInfoWidget] Status is not good, showing error and elapsed time, hiding repair.";
             m_curErrorInfoLabel->show();
             m_elapsedTimeLabel->show();
             m_repairLabel->hide();
         }
     }
 
+    qDebug() << "[CylinderInfoWidget] Showing arrow rectangle.";
     m_arrowRectangle->show(label->mapToGlobal(label->pos()).x() - label->pos().x() + (label->width() / 2),
                            label->mapToGlobal(label->pos()).y() - label->pos().y() + label->height() - 1);
 }
@@ -489,6 +553,7 @@ void CylinderInfoWidget::leaveSlot()
     CylinderWidget *label = qobject_cast<CylinderWidget *>(sender());
     QMap<QString, QVariant> mapInfo = label->getUserData().toMap();
     if (mapInfo.isEmpty()) {
+        qDebug() << "[CylinderInfoWidget] mapInfo is empty, returning from leaveSlot.";
         return;
     }
 
@@ -497,13 +562,17 @@ void CylinderInfoWidget::leaveSlot()
 
 void CylinderInfoWidget::onScrollBarValueChanged(int value)
 {
+    qDebug() << "[CylinderInfoWidget] Scroll bar value changed to:" << value;
     if (value < m_scrollBar->maximum()) {
+        qDebug() << "[CylinderInfoWidget] Scroll bar value is less than maximum, proceeding with update.";
         m_isChanged = true;
     } else {
+        qDebug() << "[CylinderInfoWidget] Scroll bar value is greater than or equal to maximum, not proceeding with update.";
         m_isChanged = false;
     }
 
     if (m_isCheck && !m_isChanged) {
+        qDebug() << "[CylinderInfoWidget] Check is in progress and scroll bar value has not changed, returning.";
         return;
     }
 
@@ -538,6 +607,7 @@ void CylinderInfoWidget::onScrollBarValueChanged(int value)
             }
         }
     }
+    qDebug() << "[CylinderInfoWidget] Scroll bar value update finished.";
 }
 
 void CylinderInfoWidget::wheelEvent(QWheelEvent *event)
